==> openjdk-src-15.0.2.u7-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ceb.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ceb extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "PHP", "\u20b1" },
            { "USD", "US $" },
            { "aed", "United Arab Emirates Dirham" },
            { "afn", "Afghan Afghani" },
            { "all", "Albanian Lek" },
            { "amd", "Armenian Dram" },
            { "ang", "Netherlands Antillean Guilder" },
            { "aoa", "Angolan Kwanza" },
            { "ars", "Argentine Peso" },
            { "aud", "Australian Dollar" },
            { "awg", "Aruban Florin" },
            { "azn", "Azerbaijani Manat" },
            { "bam", "Bosnia-Herzegovina Convertible Mark" },
            { "bbd", "Barbadian Dollar" },
            { "bdt", "Bangladeshi Taka" },
            { "bgn", "Bulgarian Lev" },
            { "bhd", "Bahraini Dinar" },
            { "bif", "Burundian Franc" },
            { "bmd", "Bermudan Dollar" },
            { "bnd", "Brunei Dollar" },
            { "bob", "Bolivian Boliviano" },
            { "brl", "Brazilian Real" },
            { "bsd", "Bahamian Dollar" },
            { "btn", "Bhutanese Ngultrum" },
            { "bwp", "Botswanan Pula" },
            { "byn", "Belarusian Ruble" },
            { "bzd", "Belize Dollar" },
            { "cad", "Canadian Dollar" },
            { "cdf", "Congolese Franc" },
            { "chf", "Swiss Franc" },
            { "clp", "Chilean Peso" },
            { "cnh", "Chinese Yuan (layo sa baybayon)" },
            { "cny", "Chinese Yuan" },
            { "cop", "Colombian Peso" },
            { "crc", "Costa Rican Colon" },
            { "cuc", "Cuban Convertible Peso" },
            { "cup", "Cuban Peso" },
            { "cve", "Cape Verdean Escudo" },
            { "czk", "Czech Koruna" },
            { "djf", "Djiboutian Franc" },
            { "dkk", "Danish Krone" },
            { "dop", "Dominican Peso" },
            { "dzd", "Algerian Dinar" },
            { "egp", "Egyptian Pound" },
            { "ern", "Eritrean Nakfa" },
            { "etb", "Ethiopian Birr" },
            { "eur", "Euro" },
            { "fjd", "Fijian Dollar" },
            { "fkp", "Falkland Islands Pound" },
            { "gbp", "British Pound" },
            { "gel", "Georgian Lari" },
            { "ghs", "Ghanaian Cedi" },
            { "gip", "Gibraltar Pound" },
            { "gmd", "Gambian Dalasi" },
            { "gnf", "Guinean Franc" },
            { "gtq", "Guatemalan Quetzal" },
            { "gyd", "Guyanaese Dollar" },
            { "hkd", "Hong Kong Dollar" },
            { "hnl", "Honduran Lempira" },
            { "hrk", "Croatian Kuna" },
            { "htg", "Haitian Gourde" },
            { "huf", "Hungarian Forint" },
            { "idr", "Indonesian Rupiah" },
            { "ils", "Israeli New Shekel" },
            { "inr", "Indian Rupee" },
            { "iqd", "Iraqi Dinar" },
            { "irr", "Iranian Rial" },
            { "isk", "Icelandic Krona" },
            { "jmd", "Jamaican Dollar" },
            { "jod", "Jordanian Dinar" },
            { "jpy", "Japanese Yen" },
            { "kes", "Kenyan Shilling" },
            { "kgs", "Kyrgystani Som" },
            { "khr", "Cambodian Riel" },
            { "kmf", "Comorian Franc" },
            { "kpw", "North Korean Won" },
            { "krw", "South Korean Won" },
            { "kwd", "Kuwaiti Dinar" },
            { "kyd", "Cayman Islands Dollar" },
            { "kzt", "Kazakhstani Tenge" },
            { "lak", "Laotian Kip" },
            { "lbp", "Lebanese Pound" },
            { "lkr", "Sri Lankan Rupee" },
            { "lrd", "Liberian Dollar" },
            { "lyd", "Libyan Dinar" },
            { "mad", "Moroccan Dirham" },
            { "mdl", "Moldovan Leu" },
            { "mga", "Malagasy Ariary" },
            { "mkd", "Macedonian Denar" },
            { "mmk", "Myanmar Kyat" },
            { "mnt", "Mongolian Tugrik" },
            { "mop", "Macanese Pataca" },
            { "mru", "Mauritanian Ouguiya" },
            { "mur", "Mauritian Rupee" },
            { "mvr", "Maldivian Rufiyaa" },
            { "mwk", "Malawian Kwacha" },
            { "mxn", "Mexican Peso" },
            { "myr", "Malaysian Ringgit" },
            { "mzn", "Mozambican Metical" },
            { "nad", "Namibian Dollar" },
            { "ngn", "Nigerian Naira" },
            { "nio", "Nicaraguan Cordoba" },
            { "nok", "Norwegian Krone" },
            { "npr", "Nepalese Rupee" },
            { "nzd", "New Zealand Dollar" },
            { "omr", "Omani Rial" },
            { "pab", "Panamanian Balboa" },
            { "pen", "Peruvian Sol" },
            { "pgk", "Papua New Guinean Kina" },
            { "php", "Philippine Piso" },
            { "pkr", "Pakistani Rupee" },
            { "pln", "Polish Zloty" },
            { "pyg", "Paraguayan Guarani" },
            { "qar", "Qatari Rial" },
            { "ron", "Romanian Leu" },
            { "rsd", "Serbian Dinar" },
            { "rub", "Russian Ruble" },
            { "rwf", "Rwandan Franc" },
            { "sar", "Saudi Riyal" },
            { "sbd", "Solomon Islands Dollar" },
            { "scr", "Seychellois Rupee" },
            { "sdg", "Sudanese Pound" },
            { "sek", "Swedish Krona" },
            { "sgd", "Singapore Dollar" },
            { "shp", "St. Helena Pound" },
            { "sll", "Sierra Leonean Leone" },
            { "sos", "Somali Shilling" },
            { "srd", "Surinamese Dollar" },
            { "ssp", "South Sudanese Pound" },
            { "stn", "Sao Tome & Principe Dobra" },
            { "syp", "Syrian Pound" },
            { "szl", "Swazi Lilangeni" },
            { "thb", "Thai Baht" },
            { "tjs", "Tajikistani Somoni" },
            { "tmt", "Turkmenistani Manat" },
            { "tnd", "Tunisian Dinar" },
            { "top", "Tongan Pa\u02bbanga" },
            { "try", "Turkish Lira" },
            { "ttd", "Trinidad & Tobago Dollar" },
            { "twd", "New Taiwan Dollar" },
            { "tzs", "Tanzanian Shilling" },
            { "uah", "Ukrainian Hryvnia" },
            { "ugx", "Ugandan Shilling" },
            { "usd", "US Dollar" },
            { "uyu", "Uruguayan Peso" },
            { "uzs", "Uzbekistani Som" },
            { "ves", "Venezuelan Bolivar" },
            { "vnd", "Vietnamese Dong" },
            { "vuv", "Vanuatu Vatu" },
            { "wst", "Samoan Tala" },
            { "xaf", "Central African CFA Franc" },
            { "xcd", "East Caribbean Dollar" },
            { "xof", "West African CFA Franc" },
            { "xpf", "CFP Franc" },
            { "xxx", "Wala Nahibaluan nga Currency" },
            { "yer", "Yemeni Rial" },
            { "zar", "South African Rand" },
            { "zmw", "Zambian Kwacha" },
        };
        return data;
    }
}

==> openjdk-src-19.0.2.u7-2-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ceb.java <==
/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ceb extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "USD", "US $" },
            { "aed", "United Arab Emirates Dirham" },
            { "afn", "Afghan Afghani" },
            { "all", "Albanian Lek" },
            { "amd", "Armenian Dram" },
            { "ang", "Netherlands Antillean Guilder" },
            { "aoa", "Angolan Kwanza" },
            { "ars", "Argentine Peso" },
            { "aud", "Australian Dollar" },
            { "awg", "Aruban Florin" },
            { "azn", "Azerbaijani Manat" },
            { "bam", "Bosnia-Herzegovina Convertible Mark" },
            { "bbd", "Barbadian Dollar" },
            { "bdt", "Bangladeshi Taka" },
            { "bgn", "Bulgarian Lev" },
            { "bhd", "Bahraini Dinar" },
            { "bif", "Burundian Franc" },
            { "bmd", "Bermudan Dollar" },
            { "bnd", "Brunei Dollar" },
            { "bob", "Bolivian Boliviano" },
            { "brl", "Brazilian Real" },
            { "bsd", "Bahamian Dollar" },
            { "btn", "Bhutanese Ngultrum" },
            { "bwp", "Botswanan Pula" },
            { "byn", "Belarusian Ruble" },
            { "bzd", "Belize Dollar" },
            { "cad", "Canadian Dollar" },
            { "cdf", "Congolese Franc" },
            { "chf", "Swiss Franc" },
            { "clp", "Chilean Peso" },
            { "cnh", "Chinese Yuan (layo sa baybayon)" },
            { "cny", "Chinese Yuan" },
            { "cop", "Colombian Peso" },
            { "crc", "Costa Rican Colon" },
            { "cuc", "Cuban Convertible Peso" },
            { "cup", "Cuban Peso" },
            { "cve", "Cape Verdean Escudo" },
            { "czk", "Czech Koruna" },
            { "djf", "Djiboutian Franc" },
            { "dkk", "Danish Krone" },
            { "dop", "Dominican Peso" },
            { "dzd", "Algerian Dinar" },
            { "egp", "Egyptian Pound" },
            { "ern", "Eritrean Nakfa" },
            { "etb", "Ethiopian Birr" },
            { "eur", "Euro" },
            { "fjd", "Fijian Dollar" },
            { "fkp", "Falkland Islands Pound" },
            { "gbp", "British Pound" },
            { "gel", "Georgian Lari" },
            { "ghs", "Ghanaian Cedi" },
            { "gip", "Gibraltar Pound" },
            { "gmd", "Gambian Dalasi" },
            { "gnf", "Guinean Franc" },
            { "gtq", "Guatemalan Quetzal" },
            { "gyd", "Guyanaese Dollar" },
            { "hkd", "Hong Kong Dollar" },
            { "hnl", "Honduran Lempira" },
            { "hrk", "Croatian Kuna" },
            { "htg", "Haitian Gourde" },
            { "huf", "Hungarian Forint" },
            { "idr", "Indonesian Rupiah" },
            { "ils", "Israeli New Shekel" },
            { "inr", "Indian Rupee" },
            { "iqd", "Iraqi Dinar" },
            { "irr", "Iranian Rial" },
            { "isk", "Icelandic Krona" },
            { "jmd", "Jamaican Dollar" },
            { "jod", "Jordanian Dinar" },
            { "jpy", "Japanese Yen" },
            { "kes", "Kenyan Shilling" },
            { "kgs", "Kyrgystani Som" },
            { "khr", "Cambodian Riel" },
            { "kmf", "Comorian Franc" },
            { "kpw", "North Korean Won" },
            { "krw", "South Korean Won" },
            { "kwd", "Kuwaiti Dinar" },
            { "kyd", "Cayman Islands Dollar" },
            { "kzt", "Kazakhstani Tenge" },
            { "lak", "Laotian Kip" },
            { "lbp", "Lebanese Pound" },
            { "lkr", "Sri Lankan Rupee" },
            { "lrd", "Liberian Dollar" },
            { "lsl", "Lesotho Loti" },
            { "lyd", "Libyan Dinar" },
            { "mad", "Moroccan Dirham" },
            { "mdl", "Moldovan Leu" },
            { "mga", "Malagasy Ariary" },
            { "mkd", "Macedonian Denar" },
            { "mmk", "Myanmar Kyat" },
            { "mnt", "Mongolian Tugrik" },
            { "mop", "Macanese Pataca" },
            { "mru", "Mauritanian Ouguiya" },
            { "mur", "Mauritian Rupee" },
            { "mvr", "Maldivian Rufiyaa" },
            { "mwk", "Malawian Kwacha" },
            { "mxn", "Mexican Peso" },
            { "myr", "Malaysian Ringgit" },
            { "mzn", "Mozambican Metical" },
            { "nad", "Namibian Dollar" },
            { "ngn", "Nigerian Naira" },
            { "nio", "Nicaraguan Cordoba" },
            { "nok", "Norwegian Krone" },
            { "npr", "Nepalese Rupee" },
            { "nzd", "New Zealand Dollar" },
            { "omr", "Omani Rial" },
            { "pab", "Panamanian Balboa" },
            { "pen", "Peruvian Sol" },
            { "pgk", "Papua New Guinean Kina" },
            { "php", "Philippine Piso" },
            { "pkr", "Pakistani Rupee" },
            { "pln", "Polish Zloty" },
            { "pyg", "Paraguayan Guarani" },
            { "qar", "Qatari Rial" },
            { "ron", "Romanian Leu" },
            { "rsd", "Serbian Dinar" },
            { "rub", "Russian Ruble" },
            { "rwf", "Rwandan Franc" },
            { "sar", "Saudi Riyal" },
            { "sbd", "Solomon Islands Dollar" },
            { "scr", "Seychellois Rupee" },
            { "sdg", "Sudanese Pound" },
            { "sek", "Swedish Krona" },
            { "sgd", "Singapore Dollar" },
            { "shp", "St. Helena Pound" },
            { "sll", "Sierra Leonean Leone" },
            { "sos", "Somali Shilling" },
            { "srd", "Surinamese Dollar" },
            { "ssp", "South Sudanese Pound" },
            { "stn", "Sao Tome & Principe Dobra" },
            { "syp", "Syrian Pound" },
            { "szl", "Swazi Lilangeni" },
            { "thb", "Thai Baht" },
            { "tjs", "Tajikistani Somoni" },
            { "tmt", "Turkmenistani Manat" },
            { "tnd", "Tunisian Dinar" },
            { "top", "Tongan Pa\u02bbanga" },
            { "try", "Turkish Lira" },
            { "ttd", "Trinidad & Tobago Dollar" },
            { "twd", "New Taiwan Dollar" },
            { "tzs", "Tanzanian Shilling" },
            { "uah", "Ukrainian Hryvnia" },
            { "ugx", "Ugandan Shilling" },
            { "usd", "US Dollar" },
            { "uyu", "Uruguayan Peso" },
            { "uzs", "Uzbekistani Som" },
            { "ves", "Venezuelan Bolivar" },
            { "vnd", "Vietnamese Dong" },
            { "vuv", "Vanuatu Vatu" },
            { "wst", "Samoan Tala" },
            { "xaf", "Central African CFA Franc" },
            { "xcd", "East Caribbean Dollar" },
            { "xof", "West African CFA Franc" },
            { "xpf", "CFP Franc" },
            { "xxx", "Wala Nailhi nga Kwarta" },
            { "yer", "Yemeni Rial" },
            { "zar", "South African Rand" },
            { "zmw", "Zambian Kwacha" },
        };
        return data;
    }
}
